@@ -26,6 +26,7 @@
 #include <QAbstractItemModel>
 #include <QAction>
 #include <QHeaderView>
+#include <QLayout>
 #include <QLineEdit>
 #include <QMessageBox>
 #include <QStandardItemModel>
@@ -103,6 +104,8 @@ private slots:
     void shouldHaveDefaultState()
     {
         Widgets::PageView page;
+        QCOMPARE(page.contentsMargins(), QMargins(0, 0, 0, 0));
+        QCOMPARE(page.layout()->contentsMargins(), QMargins(0, 0, 0, 3));
 
         auto centralView = page.findChild<QTreeView*>(QStringLiteral("centralView"));
         QVERIFY(centralView);
@@ -114,6 +117,7 @@ private slots:
 
         auto filter = page.findChild<Widgets::FilterWidget*>(QStringLiteral("filterWidget"));
         QVERIFY(filter);
+        QVERIFY(!filter->isVisibleTo(&page));
         QVERIFY(filter->proxyModel());
         QCOMPARE(filter->proxyModel(), centralView->model());
 
@@ -133,6 +137,8 @@ private slots:
         QVERIFY(promoteAction);
         auto filterAction = page.findChild<QAction*>(QStringLiteral("filterViewAction"));
         QVERIFY(filterAction);
+        QVERIFY(filterAction->isCheckable());
+        QVERIFY(!filterAction->isChecked());
 
         auto actions = page.globalActions();
         QCOMPARE(actions.value(QStringLiteral("page_view_add")), addAction);
@@ -205,6 +211,7 @@ private slots:
         centralView->setFocus();
         QVERIFY(centralView->hasFocus());
         QVERIFY(!quickAddEdit->hasFocus());
+        QVERIFY(!filter->isVisibleTo(&page));
         QVERIFY(!filterEdit->hasFocus());
 
         auto addAction = page.findChild<QAction*>(QStringLiteral("addItemAction"));
@@ -217,6 +224,7 @@ private slots:
         // THEN
         QVERIFY(!centralView->hasFocus());
         QVERIFY(quickAddEdit->hasFocus());
+        QVERIFY(!filter->isVisibleTo(&page));
         QVERIFY(!filterEdit->hasFocus());
 
         // WHEN
@@ -225,6 +233,7 @@ private slots:
         // THEN
         QVERIFY(centralView->hasFocus());
         QVERIFY(!quickAddEdit->hasFocus());
+        QVERIFY(!filter->isVisibleTo(&page));
         QVERIFY(!filterEdit->hasFocus());
 
         // WHEN
@@ -233,6 +242,7 @@ private slots:
         // THEN
         QVERIFY(!centralView->hasFocus());
         QVERIFY(!quickAddEdit->hasFocus());
+        QVERIFY(filter->isVisibleTo(&page));
         QVERIFY(filterEdit->hasFocus());
 
         // WHEN
@@ -241,9 +251,52 @@ private slots:
         // THEN
         QVERIFY(centralView->hasFocus());
         QVERIFY(!quickAddEdit->hasFocus());
+        QVERIFY(filter->isVisibleTo(&page));
         QVERIFY(!filterEdit->hasFocus());
     }
 
+    void shouldManageFilterVisibilityThroughAction()
+    {
+        // GIVEN
+        Widgets::PageView page;
+        auto centralView = page.findChild<QTreeView*>(QStringLiteral("centralView"));
+        auto filter = page.findChild<Widgets::FilterWidget*>(QStringLiteral("filterWidget"));
+        auto filterEdit = filter->findChild<QLineEdit*>();
+        QVERIFY(filterEdit);
+        page.show();
+        QTest::qWaitForWindowShown(&page);
+
+        centralView->setFocus();
+        QVERIFY(centralView->hasFocus());
+        QVERIFY(!filter->isVisibleTo(&page));
+        QVERIFY(!filterEdit->hasFocus());
+
+        auto filterAction = page.findChild<QAction*>(QStringLiteral("filterViewAction"));
+
+        // WHEN
+        filterAction->trigger();
+
+        // THEN
+        QVERIFY(!centralView->hasFocus());
+        QVERIFY(filter->isVisibleTo(&page));
+        QVERIFY(filterEdit->hasFocus());
+
+        // WHEN
+        filterEdit->setText("Foo");
+
+        // THEN
+        QCOMPARE(filterEdit->text(), QString("Foo"));
+
+        // WHEN
+        filterAction->trigger();
+
+        // THEN
+        QVERIFY(centralView->hasFocus());
+        QVERIFY(!filter->isVisibleTo(&page));
+        QVERIFY(!filterEdit->hasFocus());
+        QVERIFY(filterEdit->text().isEmpty());
+    }
+
     void shouldCreateTasksWithNoParentWhenHittingReturnWithoutSelectedIndex()
     {
         // GIVEN
